# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: epl/protobuf/v1/geometry.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='epl/protobuf/v1/geometry.proto',
  package='epl.protobuf.v1',
  syntax='proto3',
  serialized_options=b'\n\023com.epl.protobuf.v1B\rGeometryProtoP\001Z.github.com/geo-grpc/api/golang/epl/protobuf/v1\242\002\004GMPB',
  serialized_pb=b'\n\x1e\x65pl/protobuf/v1/geometry.proto\x12\x0f\x65pl.protobuf.v1\"\x9a\x02\n\x0cGeometryData\x12\x13\n\x0bgeometry_id\x18\x01 \x01(\x04\x12\x12\n\nfeature_id\x18\x02 \x01(\t\x12\r\n\x03wkt\x18\x03 \x01(\tH\x00\x12\x11\n\x07geojson\x18\x04 \x01(\tH\x00\x12\r\n\x03wkb\x18\x05 \x01(\x0cH\x00\x12\x14\n\nesri_shape\x18\x06 \x01(\x0cH\x00\x12-\n\x04proj\x18\x07 \x01(\x0b\x32\x1f.epl.protobuf.v1.ProjectionData\x12/\n\x08\x65nvelope\x18\r \x01(\x0b\x32\x1d.epl.protobuf.v1.EnvelopeData\x12,\n\x06simple\x18\x0e \x01(\x0e\x32\x1c.epl.protobuf.v1.SimpleStateB\x06\n\x04\x64\x61taJ\x04\x08\x08\x10\r\"\xc7\x03\n\x0eProjectionData\x12\x0e\n\x04\x65psg\x18\x01 \x01(\x05H\x00\x12\x0f\n\x05proj4\x18\x02 \x01(\tH\x00\x12\x38\n\x06\x63ustom\x18\x03 \x01(\x0b\x32&.epl.protobuf.v1.ProjectionData.CustomH\x00\x12\r\n\x03wkt\x18\x04 \x01(\tH\x00\x12/\n\x08geometry\x18\n \x01(\x0b\x32\x1d.epl.protobuf.v1.GeometryData\x12+\n\x04\x62\x62ox\x18\x0b \x01(\x0b\x32\x1d.epl.protobuf.v1.EnvelopeData\x12/\n\x08\x63\x65ntroid\x18\x0c \x01(\x0b\x32\x1d.epl.protobuf.v1.GeometryData\x12\r\n\x05shape\x18\x08 \x03(\r\x12\x11\n\ttransform\x18\t \x03(\x01\x1a_\n\x06\x43ustom\x12\r\n\x05lon_0\x18\x01 \x01(\x01\x12\r\n\x05lat_0\x18\x02 \x01(\x01\x12\x37\n\x07\x63s_type\x18\x03 \x01(\x0e\x32&.epl.protobuf.v1.ProjectionData.CSType\"\x19\n\x06\x43SType\x12\x0f\n\x0bLAMBERT_AZI\x10\x00\x42\x0c\n\ndefinitionJ\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08\"\x91\x01\n\x0c\x45nvelopeData\x12\x0c\n\x04xmin\x18\x01 \x01(\x01\x12\x0c\n\x04ymin\x18\x02 \x01(\x01\x12\x0c\n\x04xmax\x18\x03 \x01(\x01\x12\x0c\n\x04ymax\x18\x04 \x01(\x01\x12-\n\x04proj\x18\x05 \x01(\x0b\x32\x1f.epl.protobuf.v1.ProjectionData\x12\x0c\n\x04zmin\x18\x06 \x01(\x01\x12\x0c\n\x04zmax\x18\x07 \x01(\x01\"\xde\x0b\n\x0fGeometryRequest\x12\x31\n\x08geometry\x18\x01 \x01(\x0b\x32\x1d.epl.protobuf.v1.GeometryDataH\x00\x12\x36\n\rleft_geometry\x18\x02 \x01(\x0b\x32\x1d.epl.protobuf.v1.GeometryDataH\x00\x12<\n\x10geometry_request\x18\x03 \x01(\x0b\x32 .epl.protobuf.v1.GeometryRequestH\x00\x12\x41\n\x15left_geometry_request\x18\x04 \x01(\x0b\x32 .epl.protobuf.v1.GeometryRequestH\x00\x12\x37\n\x0eright_geometry\x18\x05 \x01(\x0b\x32\x1d.epl.protobuf.v1.GeometryDataH\x01\x12\x42\n\x16right_geometry_request\x18\x06 \x01(\x0b\x32 .epl.protobuf.v1.GeometryRequestH\x01\x12/\n\x08operator\x18\x07 \x01(\x0e\x32\x1d.epl.protobuf.v1.OperatorType\x12\x32\n\x0fresult_encoding\x18\x08 \x01(\x0e\x32\x19.epl.protobuf.v1.Encoding\x12\x37\n\x0eoperation_proj\x18\t \x01(\x0b\x32\x1f.epl.protobuf.v1.ProjectionData\x12\x34\n\x0bresult_proj\x18\n \x01(\x0b\x32\x1f.epl.protobuf.v1.ProjectionData\x12\x37\n\rbuffer_params\x18\x0b \x01(\x0b\x32\x1e.epl.protobuf.v1.Params.BufferH\x02\x12\x37\n\rconvex_params\x18\x0c \x01(\x0b\x32\x1e.epl.protobuf.v1.Params.ConvexH\x02\x12\x37\n\rrelate_params\x18\r \x01(\x0b\x32\x1e.epl.protobuf.v1.Params.RelateH\x02\x12\x44\n\x14random_points_params\x18\x0e \x01(\x0b\x32$.epl.protobuf.v1.Params.RandomPointsH\x02\x12?\n\x11generalize_params\x18\x0f \x01(\x0b\x32\".epl.protobuf.v1.Params.GeneralizeH\x02\x12\x43\n\x13intersection_params\x18\x10 \x01(\x0b\x32$.epl.protobuf.v1.Params.IntersectionH\x02\x12\x37\n\roffset_params\x18\x11 \x01(\x0b\x32\x1e.epl.protobuf.v1.Params.OffsetH\x02\x12\x31\n\ncut_params\x18\x12 \x01(\x0b\x32\x1b.epl.protobuf.v1.Params.CutH\x02\x12\x33\n\x0b\x63lip_params\x18\x13 \x01(\x0b\x32\x1c.epl.protobuf.v1.Params.ClipH\x02\x12\x39\n\x0e\x64\x65nsify_params\x18\x14 \x01(\x0b\x32\x1f.epl.protobuf.v1.Params.DensifyH\x02\x12;\n\x0fsimplify_params\x18\x15 \x01(\x0b\x32 .epl.protobuf.v1.Params.SimplifyH\x02\x12M\n\x19generalize_by_area_params\x18\x16 \x01(\x0b\x32(.epl.protobuf.v1.Params.GeneralizeByAreaH\x02\x12J\n\x17\x61\x66\x66ine_transform_params\x18\x17 \x01(\x0b\x32\'.epl.protobuf.v1.Params.AffineTransformH\x02\x12H\n\x16geodetic_buffer_params\x18\x18 \x01(\x0b\x32&.epl.protobuf.v1.Params.GeodeticBufferH\x02\x42\x06\n\x04leftB\x07\n\x05rightB\x08\n\x06params\"?\n\x0fGeodeticInverse\x12\x0c\n\x04\x61z12\x18\x01 \x01(\x01\x12\x0c\n\x04\x61z21\x18\x02 \x01(\x01\x12\x10\n\x08\x64istance\x18\x03 \x01(\x01\"\xb8\x02\n\x10GeometryResponse\x12\x31\n\x08geometry\x18\x01 \x01(\x0b\x32\x1d.epl.protobuf.v1.GeometryDataH\x00\x12\x1e\n\x14spatial_relationship\x18\x02 \x01(\x08H\x00\x12\x11\n\x07measure\x18\x03 \x01(\x01H\x00\x12<\n\x10geodetic_inverse\x18\x04 \x01(\x0b\x32 .epl.protobuf.v1.GeodeticInverseH\x00\x12\x44\n\nrelate_map\x18\x05 \x03(\x0b\x32\x30.epl.protobuf.v1.GeometryResponse.RelateMapEntry\x1a\x30\n\x0eRelateMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x42\x08\n\x06result\"\xe1\x02\n\x10\x46ileRequestChunk\x12\x38\n\x0enested_request\x18\x01 \x01(\x0b\x32 .epl.protobuf.v1.GeometryRequest\x12\x37\n\x14result_encoding_type\x18\x02 \x01(\x0e\x32\x19.epl.protobuf.v1.Encoding\x12\x33\n\ninput_proj\x18\x03 \x01(\x0b\x32\x1f.epl.protobuf.v1.ProjectionData\x12\x34\n\x0bresult_proj\x18\x05 \x01(\x0b\x32\x1f.epl.protobuf.v1.ProjectionData\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\x0c\n\x04size\x18\x07 \x01(\x03\x12\x0e\n\x06offset\x18\x08 \x01(\x03\x12\x11\n\tfile_name\x18\t \x01(\t\x12\x15\n\ris_last_chunk\x18\n \x01(\x08\"\x19\n\x08\x46ileType\x12\r\n\tSHAPEFILE\x10\x00\"\xd3\x07\n\x06Params\x1al\n\x06\x42uffer\x12\x10\n\x08\x64istance\x18\x01 \x01(\x01\x12\x15\n\rmax_deviation\x18\x02 \x01(\x01\x12\x14\n\x0cunion_result\x18\x03 \x01(\x08\x12#\n\x1bmax_vertices_in_full_circle\x18\x04 \x01(\x05\x1at\n\x0eGeodeticBuffer\x12\x10\n\x08\x64istance\x18\x01 \x01(\x01\x12\x15\n\rmax_deviation\x18\x02 \x01(\x01\x12\x14\n\x0cunion_result\x18\x03 \x01(\x08\x12#\n\x1bmax_vertices_in_full_circle\x18\x04 \x01(\x05\x1a\x17\n\x06\x43onvex\x12\r\n\x05merge\x18\x01 \x01(\x08\x1a\x18\n\x06Relate\x12\x0e\n\x06\x64\x65_9im\x18\x01 \x01(\t\x1a:\n\x0cRandomPoints\x12\x1c\n\x14points_per_square_km\x18\x01 \x01(\x01\x12\x0c\n\x04seed\x18\x02 \x01(\x03\x1a?\n\nGeneralize\x12\x15\n\rmax_deviation\x18\x01 \x01(\x01\x12\x1a\n\x12remove_degenerates\x18\x02 \x01(\x08\x1a\x62\n\x10GeneralizeByArea\x12\x19\n\x11percent_reduction\x18\x01 \x01(\x01\x12\x17\n\x0fmax_point_count\x18\x02 \x01(\x05\x12\x1a\n\x12remove_degenerates\x18\x03 \x01(\x08\x1a&\n\x0cIntersection\x12\x16\n\x0e\x64imension_mask\x18\x01 \x01(\x05\x1a\xc7\x01\n\x06Offset\x12\x10\n\x08\x64istance\x18\x01 \x01(\x01\x12@\n\tjoin_type\x18\x02 \x01(\x0e\x32-.epl.protobuf.v1.Params.Offset.OffsetJoinType\x12\x13\n\x0b\x62\x65vel_ratio\x18\x03 \x01(\x01\x12\x15\n\rflatten_error\x18\x04 \x01(\x01\"=\n\x0eOffsetJoinType\x12\t\n\x05ROUND\x10\x00\x12\t\n\x05\x42\x45VEL\x10\x01\x12\t\n\x05MITER\x10\x02\x12\n\n\x06SQUARE\x10\x03\x1a\x1d\n\x03\x43ut\x12\x16\n\x0e\x63onsider_touch\x18\x01 \x01(\x08\x1a\x37\n\x04\x43lip\x12/\n\x08\x65nvelope\x18\x01 \x01(\x0b\x32\x1d.epl.protobuf.v1.EnvelopeData\x1a\x1d\n\x07\x44\x65nsify\x12\x12\n\nmax_length\x18\x01 \x01(\x01\x1a\x19\n\x08Simplify\x12\r\n\x05\x66orce\x18\x01 \x01(\x08\x1aM\n\x0f\x41\x66\x66ineTransform\x12\x10\n\x08geodetic\x18\x02 \x01(\x08\x12\x10\n\x08x_offset\x18\x03 \x01(\x01\x12\x10\n\x08y_offset\x18\x04 \x01(\x01J\x04\x08\x01\x10\x02*\xc6\x01\n\x0bSimpleState\x12\x12\n\x0eSIMPLE_UNKNOWN\x10\x00\x12\x0f\n\x0bWEAK_SIMPLE\x10\x01\x12\x11\n\rSTRONG_SIMPLE\x10\x02\x12\x0e\n\nNON_SIMPLE\x10\x03\x12\x12\n\x0eSTRUCTURE_FLAW\x10\x04\x12\x17\n\x13\x44\x45GENERATE_SEGMENTS\x10\x05\x12\x0e\n\nCLUSTERING\x10\x06\x12\x0c\n\x08\x43RACKING\x10\x07\x12\x0e\n\nCROSS_OVER\x10\x08\x12\x14\n\x10RING_ORIENTATION\x10\t*O\n\x08\x45ncoding\x12\x14\n\x10UNKNOWN_ENCODING\x10\x00\x12\x07\n\x03WKB\x10\x01\x12\x07\n\x03WKT\x10\x02\x12\x0b\n\x07GEOJSON\x10\x03\x12\x0e\n\nESRI_SHAPE\x10\x04*\xcb\x06\n\x0cOperatorType\x12\x14\n\x10UNKNOWN_OPERATOR\x10\x00\x12\x0b\n\x07PROJECT\x10\x01\x12\x12\n\x0e\x45XPORT_TO_JSON\x10\x02\x12\x14\n\x10IMPORT_FROM_JSON\x10\x03\x12\x18\n\x14\x45XPORT_TO_ESRI_SHAPE\x10\x04\x12\x1a\n\x16IMPORT_FROM_ESRI_SHAPE\x10\x05\x12\t\n\x05UNION\x10\x06\x12\x0e\n\nDIFFERENCE\x10\x07\x12\x10\n\x0cPROXIMITY_2D\x10\x08\x12\n\n\x06RELATE\x10\t\x12\n\n\x06\x45QUALS\x10\n\x12\x0c\n\x08\x44ISJOINT\x10\x0b\x12\x0e\n\nINTERSECTS\x10\x0c\x12\n\n\x06WITHIN\x10\r\x12\x0c\n\x08\x43ONTAINS\x10\x0e\x12\x0b\n\x07\x43ROSSES\x10\x0f\x12\x0b\n\x07TOUCHES\x10\x10\x12\x0c\n\x08OVERLAPS\x10\x11\x12\n\n\x06\x42UFFER\x10\x12\x12\x0c\n\x08\x44ISTANCE\x10\x13\x12\x10\n\x0cINTERSECTION\x10\x14\x12\x08\n\x04\x43LIP\x10\x15\x12\x07\n\x03\x43UT\x10\x16\x12\x15\n\x11\x44\x45NSIFY_BY_LENGTH\x10\x17\x12\x13\n\x0fGEODESIC_BUFFER\x10\x1a\x12\x1e\n\x1aGEODETIC_DENSIFY_BY_LENGTH\x10\x1b\x12\x11\n\rGEODETIC_AREA\x10\x1e\x12\x0c\n\x08SIMPLIFY\x10\x1f\x12\x10\n\x0cSIMPLIFY_OGC\x10 \x12\n\n\x06OFFSET\x10!\x12\x0e\n\nGENERALIZE\x10\"\x12\x16\n\x12GENERALIZE_BY_AREA\x10#\x12\x11\n\rEXPORT_TO_WKB\x10$\x12\x13\n\x0fIMPORT_FROM_WKB\x10%\x12\x11\n\rEXPORT_TO_WKT\x10&\x12\x13\n\x0fIMPORT_FROM_WKT\x10\'\x12\x17\n\x13IMPORT_FROM_GEOJSON\x10(\x12\x15\n\x11\x45XPORT_TO_GEOJSON\x10)\x12\x18\n\x14SYMMETRIC_DIFFERENCE\x10*\x12\x0f\n\x0b\x43ONVEX_HULL\x10+\x12\x0c\n\x08\x42OUNDARY\x10,\x12\x11\n\rRANDOM_POINTS\x10-\x12\x14\n\x10\x45NCLOSING_CIRCLE\x10.\x12\x14\n\x10\x41\x46\x46INE_TRANSFORM\x10/\x12\x13\n\x0fGEODETIC_LENGTH\x10\x30\x12\x14\n\x10GEODETIC_INVERSE\x10\x31\x42]\n\x13\x63om.epl.protobuf.v1B\rGeometryProtoP\x01Z.github.com/geo-grpc/api/golang/epl/protobuf/v1\xa2\x02\x04GMPBb\x06proto3'
)

_SIMPLESTATE = _descriptor.EnumDescriptor(
  name='SimpleState',
  full_name='epl.protobuf.v1.SimpleState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SIMPLE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEAK_SIMPLE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRONG_SIMPLE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NON_SIMPLE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRUCTURE_FLAW', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEGENERATE_SEGMENTS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLUSTERING', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CRACKING', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CROSS_OVER', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RING_ORIENTATION', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4166,
  serialized_end=4364,
)
_sym_db.RegisterEnumDescriptor(_SIMPLESTATE)

SimpleState = enum_type_wrapper.EnumTypeWrapper(_SIMPLESTATE)
_ENCODING = _descriptor.EnumDescriptor(
  name='Encoding',
  full_name='epl.protobuf.v1.Encoding',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ENCODING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WKB', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WKT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEOJSON', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ESRI_SHAPE', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4366,
  serialized_end=4445,
)
_sym_db.RegisterEnumDescriptor(_ENCODING)

Encoding = enum_type_wrapper.EnumTypeWrapper(_ENCODING)
_OPERATORTYPE = _descriptor.EnumDescriptor(
  name='OperatorType',
  full_name='epl.protobuf.v1.OperatorType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_OPERATOR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROJECT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPORT_TO_JSON', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMPORT_FROM_JSON', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPORT_TO_ESRI_SHAPE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMPORT_FROM_ESRI_SHAPE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNION', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIFFERENCE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROXIMITY_2D', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RELATE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUALS', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISJOINT', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERSECTS', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTAINS', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CROSSES', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOUCHES', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OVERLAPS', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BUFFER', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISTANCE', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERSECTION', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIP', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUT', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DENSIFY_BY_LENGTH', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEODESIC_BUFFER', index=24, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEODETIC_DENSIFY_BY_LENGTH', index=25, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEODETIC_AREA', index=26, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIMPLIFY', index=27, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIMPLIFY_OGC', index=28, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OFFSET', index=29, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GENERALIZE', index=30, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GENERALIZE_BY_AREA', index=31, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPORT_TO_WKB', index=32, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMPORT_FROM_WKB', index=33, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPORT_TO_WKT', index=34, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMPORT_FROM_WKT', index=35, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMPORT_FROM_GEOJSON', index=36, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPORT_TO_GEOJSON', index=37, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYMMETRIC_DIFFERENCE', index=38, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVEX_HULL', index=39, number=43,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOUNDARY', index=40, number=44,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RANDOM_POINTS', index=41, number=45,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENCLOSING_CIRCLE', index=42, number=46,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AFFINE_TRANSFORM', index=43, number=47,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEODETIC_LENGTH', index=44, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEODETIC_INVERSE', index=45, number=49,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4448,
  serialized_end=5291,
)
_sym_db.RegisterEnumDescriptor(_OPERATORTYPE)

OperatorType = enum_type_wrapper.EnumTypeWrapper(_OPERATORTYPE)
SIMPLE_UNKNOWN = 0
WEAK_SIMPLE = 1
STRONG_SIMPLE = 2
NON_SIMPLE = 3
STRUCTURE_FLAW = 4
DEGENERATE_SEGMENTS = 5
CLUSTERING = 6
CRACKING = 7
CROSS_OVER = 8
RING_ORIENTATION = 9
UNKNOWN_ENCODING = 0
WKB = 1
WKT = 2
GEOJSON = 3
ESRI_SHAPE = 4
UNKNOWN_OPERATOR = 0
PROJECT = 1
EXPORT_TO_JSON = 2
IMPORT_FROM_JSON = 3
EXPORT_TO_ESRI_SHAPE = 4
IMPORT_FROM_ESRI_SHAPE = 5
UNION = 6
DIFFERENCE = 7
PROXIMITY_2D = 8
RELATE = 9
EQUALS = 10
DISJOINT = 11
INTERSECTS = 12
WITHIN = 13
CONTAINS = 14
CROSSES = 15
TOUCHES = 16
OVERLAPS = 17
BUFFER = 18
DISTANCE = 19
INTERSECTION = 20
CLIP = 21
CUT = 22
DENSIFY_BY_LENGTH = 23
GEODESIC_BUFFER = 26
GEODETIC_DENSIFY_BY_LENGTH = 27
GEODETIC_AREA = 30
SIMPLIFY = 31
SIMPLIFY_OGC = 32
OFFSET = 33
GENERALIZE = 34
GENERALIZE_BY_AREA = 35
EXPORT_TO_WKB = 36
IMPORT_FROM_WKB = 37
EXPORT_TO_WKT = 38
IMPORT_FROM_WKT = 39
IMPORT_FROM_GEOJSON = 40
EXPORT_TO_GEOJSON = 41
SYMMETRIC_DIFFERENCE = 42
CONVEX_HULL = 43
BOUNDARY = 44
RANDOM_POINTS = 45
ENCLOSING_CIRCLE = 46
AFFINE_TRANSFORM = 47
GEODETIC_LENGTH = 48
GEODETIC_INVERSE = 49


_PROJECTIONDATA_CSTYPE = _descriptor.EnumDescriptor(
  name='CSType',
  full_name='epl.protobuf.v1.ProjectionData.CSType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LAMBERT_AZI', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=735,
  serialized_end=760,
)
_sym_db.RegisterEnumDescriptor(_PROJECTIONDATA_CSTYPE)

_FILEREQUESTCHUNK_FILETYPE = _descriptor.EnumDescriptor(
  name='FileType',
  full_name='epl.protobuf.v1.FileRequestChunk.FileType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHAPEFILE', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3156,
  serialized_end=3181,
)
_sym_db.RegisterEnumDescriptor(_FILEREQUESTCHUNK_FILETYPE)

_PARAMS_OFFSET_OFFSETJOINTYPE = _descriptor.EnumDescriptor(
  name='OffsetJoinType',
  full_name='epl.protobuf.v1.Params.Offset.OffsetJoinType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ROUND', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BEVEL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MITER', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SQUARE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3877,
  serialized_end=3938,
)
_sym_db.RegisterEnumDescriptor(_PARAMS_OFFSET_OFFSETJOINTYPE)


_GEOMETRYDATA = _descriptor.Descriptor(
  name='GeometryData',
  full_name='epl.protobuf.v1.GeometryData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='geometry_id', full_name='epl.protobuf.v1.GeometryData.geometry_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feature_id', full_name='epl.protobuf.v1.GeometryData.feature_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wkt', full_name='epl.protobuf.v1.GeometryData.wkt', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geojson', full_name='epl.protobuf.v1.GeometryData.geojson', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wkb', full_name='epl.protobuf.v1.GeometryData.wkb', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='esri_shape', full_name='epl.protobuf.v1.GeometryData.esri_shape', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proj', full_name='epl.protobuf.v1.GeometryData.proj', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='envelope', full_name='epl.protobuf.v1.GeometryData.envelope', index=7,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='simple', full_name='epl.protobuf.v1.GeometryData.simple', index=8,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='epl.protobuf.v1.GeometryData.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=52,
  serialized_end=334,
)


_PROJECTIONDATA_CUSTOM = _descriptor.Descriptor(
  name='Custom',
  full_name='epl.protobuf.v1.ProjectionData.Custom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lon_0', full_name='epl.protobuf.v1.ProjectionData.Custom.lon_0', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lat_0', full_name='epl.protobuf.v1.ProjectionData.Custom.lat_0', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cs_type', full_name='epl.protobuf.v1.ProjectionData.Custom.cs_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=638,
  serialized_end=733,
)

_PROJECTIONDATA = _descriptor.Descriptor(
  name='ProjectionData',
  full_name='epl.protobuf.v1.ProjectionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='epsg', full_name='epl.protobuf.v1.ProjectionData.epsg', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proj4', full_name='epl.protobuf.v1.ProjectionData.proj4', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom', full_name='epl.protobuf.v1.ProjectionData.custom', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wkt', full_name='epl.protobuf.v1.ProjectionData.wkt', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geometry', full_name='epl.protobuf.v1.ProjectionData.geometry', index=4,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bbox', full_name='epl.protobuf.v1.ProjectionData.bbox', index=5,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='centroid', full_name='epl.protobuf.v1.ProjectionData.centroid', index=6,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape', full_name='epl.protobuf.v1.ProjectionData.shape', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transform', full_name='epl.protobuf.v1.ProjectionData.transform', index=8,
      number=9, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PROJECTIONDATA_CUSTOM, ],
  enum_types=[
    _PROJECTIONDATA_CSTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='definition', full_name='epl.protobuf.v1.ProjectionData.definition',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=337,
  serialized_end=792,
)


_ENVELOPEDATA = _descriptor.Descriptor(
  name='EnvelopeData',
  full_name='epl.protobuf.v1.EnvelopeData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='xmin', full_name='epl.protobuf.v1.EnvelopeData.xmin', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ymin', full_name='epl.protobuf.v1.EnvelopeData.ymin', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xmax', full_name='epl.protobuf.v1.EnvelopeData.xmax', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ymax', full_name='epl.protobuf.v1.EnvelopeData.ymax', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proj', full_name='epl.protobuf.v1.EnvelopeData.proj', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zmin', full_name='epl.protobuf.v1.EnvelopeData.zmin', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zmax', full_name='epl.protobuf.v1.EnvelopeData.zmax', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=795,
  serialized_end=940,
)


_GEOMETRYREQUEST = _descriptor.Descriptor(
  name='GeometryRequest',
  full_name='epl.protobuf.v1.GeometryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='geometry', full_name='epl.protobuf.v1.GeometryRequest.geometry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left_geometry', full_name='epl.protobuf.v1.GeometryRequest.left_geometry', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geometry_request', full_name='epl.protobuf.v1.GeometryRequest.geometry_request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left_geometry_request', full_name='epl.protobuf.v1.GeometryRequest.left_geometry_request', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right_geometry', full_name='epl.protobuf.v1.GeometryRequest.right_geometry', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right_geometry_request', full_name='epl.protobuf.v1.GeometryRequest.right_geometry_request', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operator', full_name='epl.protobuf.v1.GeometryRequest.operator', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result_encoding', full_name='epl.protobuf.v1.GeometryRequest.result_encoding', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation_proj', full_name='epl.protobuf.v1.GeometryRequest.operation_proj', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result_proj', full_name='epl.protobuf.v1.GeometryRequest.result_proj', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buffer_params', full_name='epl.protobuf.v1.GeometryRequest.buffer_params', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='convex_params', full_name='epl.protobuf.v1.GeometryRequest.convex_params', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relate_params', full_name='epl.protobuf.v1.GeometryRequest.relate_params', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='random_points_params', full_name='epl.protobuf.v1.GeometryRequest.random_points_params', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generalize_params', full_name='epl.protobuf.v1.GeometryRequest.generalize_params', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intersection_params', full_name='epl.protobuf.v1.GeometryRequest.intersection_params', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset_params', full_name='epl.protobuf.v1.GeometryRequest.offset_params', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cut_params', full_name='epl.protobuf.v1.GeometryRequest.cut_params', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clip_params', full_name='epl.protobuf.v1.GeometryRequest.clip_params', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='densify_params', full_name='epl.protobuf.v1.GeometryRequest.densify_params', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='simplify_params', full_name='epl.protobuf.v1.GeometryRequest.simplify_params', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generalize_by_area_params', full_name='epl.protobuf.v1.GeometryRequest.generalize_by_area_params', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='affine_transform_params', full_name='epl.protobuf.v1.GeometryRequest.affine_transform_params', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geodetic_buffer_params', full_name='epl.protobuf.v1.GeometryRequest.geodetic_buffer_params', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='left', full_name='epl.protobuf.v1.GeometryRequest.left',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='right', full_name='epl.protobuf.v1.GeometryRequest.right',
      index=1, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='params', full_name='epl.protobuf.v1.GeometryRequest.params',
      index=2, containing_type=None, fields=[]),
  ],
  serialized_start=943,
  serialized_end=2445,
)


_GEODETICINVERSE = _descriptor.Descriptor(
  name='GeodeticInverse',
  full_name='epl.protobuf.v1.GeodeticInverse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='az12', full_name='epl.protobuf.v1.GeodeticInverse.az12', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='az21', full_name='epl.protobuf.v1.GeodeticInverse.az21', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distance', full_name='epl.protobuf.v1.GeodeticInverse.distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2447,
  serialized_end=2510,
)


_GEOMETRYRESPONSE_RELATEMAPENTRY = _descriptor.Descriptor(
  name='RelateMapEntry',
  full_name='epl.protobuf.v1.GeometryResponse.RelateMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='epl.protobuf.v1.GeometryResponse.RelateMapEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='epl.protobuf.v1.GeometryResponse.RelateMapEntry.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2767,
  serialized_end=2815,
)

_GEOMETRYRESPONSE = _descriptor.Descriptor(
  name='GeometryResponse',
  full_name='epl.protobuf.v1.GeometryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='geometry', full_name='epl.protobuf.v1.GeometryResponse.geometry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spatial_relationship', full_name='epl.protobuf.v1.GeometryResponse.spatial_relationship', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='measure', full_name='epl.protobuf.v1.GeometryResponse.measure', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geodetic_inverse', full_name='epl.protobuf.v1.GeometryResponse.geodetic_inverse', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relate_map', full_name='epl.protobuf.v1.GeometryResponse.relate_map', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GEOMETRYRESPONSE_RELATEMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='epl.protobuf.v1.GeometryResponse.result',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2513,
  serialized_end=2825,
)


_FILEREQUESTCHUNK = _descriptor.Descriptor(
  name='FileRequestChunk',
  full_name='epl.protobuf.v1.FileRequestChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nested_request', full_name='epl.protobuf.v1.FileRequestChunk.nested_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result_encoding_type', full_name='epl.protobuf.v1.FileRequestChunk.result_encoding_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_proj', full_name='epl.protobuf.v1.FileRequestChunk.input_proj', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result_proj', full_name='epl.protobuf.v1.FileRequestChunk.result_proj', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='epl.protobuf.v1.FileRequestChunk.data', index=4,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='epl.protobuf.v1.FileRequestChunk.size', index=5,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='epl.protobuf.v1.FileRequestChunk.offset', index=6,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='epl.protobuf.v1.FileRequestChunk.file_name', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_last_chunk', full_name='epl.protobuf.v1.FileRequestChunk.is_last_chunk', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FILEREQUESTCHUNK_FILETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2828,
  serialized_end=3181,
)


_PARAMS_BUFFER = _descriptor.Descriptor(
  name='Buffer',
  full_name='epl.protobuf.v1.Params.Buffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='distance', full_name='epl.protobuf.v1.Params.Buffer.distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_deviation', full_name='epl.protobuf.v1.Params.Buffer.max_deviation', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='union_result', full_name='epl.protobuf.v1.Params.Buffer.union_result', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_vertices_in_full_circle', full_name='epl.protobuf.v1.Params.Buffer.max_vertices_in_full_circle', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3194,
  serialized_end=3302,
)

_PARAMS_GEODETICBUFFER = _descriptor.Descriptor(
  name='GeodeticBuffer',
  full_name='epl.protobuf.v1.Params.GeodeticBuffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='distance', full_name='epl.protobuf.v1.Params.GeodeticBuffer.distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_deviation', full_name='epl.protobuf.v1.Params.GeodeticBuffer.max_deviation', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='union_result', full_name='epl.protobuf.v1.Params.GeodeticBuffer.union_result', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_vertices_in_full_circle', full_name='epl.protobuf.v1.Params.GeodeticBuffer.max_vertices_in_full_circle', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3304,
  serialized_end=3420,
)

_PARAMS_CONVEX = _descriptor.Descriptor(
  name='Convex',
  full_name='epl.protobuf.v1.Params.Convex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='merge', full_name='epl.protobuf.v1.Params.Convex.merge', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3422,
  serialized_end=3445,
)

_PARAMS_RELATE = _descriptor.Descriptor(
  name='Relate',
  full_name='epl.protobuf.v1.Params.Relate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='de_9im', full_name='epl.protobuf.v1.Params.Relate.de_9im', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3447,
  serialized_end=3471,
)

_PARAMS_RANDOMPOINTS = _descriptor.Descriptor(
  name='RandomPoints',
  full_name='epl.protobuf.v1.Params.RandomPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='points_per_square_km', full_name='epl.protobuf.v1.Params.RandomPoints.points_per_square_km', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seed', full_name='epl.protobuf.v1.Params.RandomPoints.seed', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3473,
  serialized_end=3531,
)

_PARAMS_GENERALIZE = _descriptor.Descriptor(
  name='Generalize',
  full_name='epl.protobuf.v1.Params.Generalize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_deviation', full_name='epl.protobuf.v1.Params.Generalize.max_deviation', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove_degenerates', full_name='epl.protobuf.v1.Params.Generalize.remove_degenerates', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3533,
  serialized_end=3596,
)

_PARAMS_GENERALIZEBYAREA = _descriptor.Descriptor(
  name='GeneralizeByArea',
  full_name='epl.protobuf.v1.Params.GeneralizeByArea',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='percent_reduction', full_name='epl.protobuf.v1.Params.GeneralizeByArea.percent_reduction', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_point_count', full_name='epl.protobuf.v1.Params.GeneralizeByArea.max_point_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove_degenerates', full_name='epl.protobuf.v1.Params.GeneralizeByArea.remove_degenerates', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3598,
  serialized_end=3696,
)

_PARAMS_INTERSECTION = _descriptor.Descriptor(
  name='Intersection',
  full_name='epl.protobuf.v1.Params.Intersection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dimension_mask', full_name='epl.protobuf.v1.Params.Intersection.dimension_mask', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3698,
  serialized_end=3736,
)

_PARAMS_OFFSET = _descriptor.Descriptor(
  name='Offset',
  full_name='epl.protobuf.v1.Params.Offset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='distance', full_name='epl.protobuf.v1.Params.Offset.distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='join_type', full_name='epl.protobuf.v1.Params.Offset.join_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bevel_ratio', full_name='epl.protobuf.v1.Params.Offset.bevel_ratio', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flatten_error', full_name='epl.protobuf.v1.Params.Offset.flatten_error', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PARAMS_OFFSET_OFFSETJOINTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3739,
  serialized_end=3938,
)

_PARAMS_CUT = _descriptor.Descriptor(
  name='Cut',
  full_name='epl.protobuf.v1.Params.Cut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='consider_touch', full_name='epl.protobuf.v1.Params.Cut.consider_touch', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3940,
  serialized_end=3969,
)

_PARAMS_CLIP = _descriptor.Descriptor(
  name='Clip',
  full_name='epl.protobuf.v1.Params.Clip',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='envelope', full_name='epl.protobuf.v1.Params.Clip.envelope', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3971,
  serialized_end=4026,
)

_PARAMS_DENSIFY = _descriptor.Descriptor(
  name='Densify',
  full_name='epl.protobuf.v1.Params.Densify',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_length', full_name='epl.protobuf.v1.Params.Densify.max_length', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4028,
  serialized_end=4057,
)

_PARAMS_SIMPLIFY = _descriptor.Descriptor(
  name='Simplify',
  full_name='epl.protobuf.v1.Params.Simplify',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='force', full_name='epl.protobuf.v1.Params.Simplify.force', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4059,
  serialized_end=4084,
)

_PARAMS_AFFINETRANSFORM = _descriptor.Descriptor(
  name='AffineTransform',
  full_name='epl.protobuf.v1.Params.AffineTransform',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='geodetic', full_name='epl.protobuf.v1.Params.AffineTransform.geodetic', index=0,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='x_offset', full_name='epl.protobuf.v1.Params.AffineTransform.x_offset', index=1,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y_offset', full_name='epl.protobuf.v1.Params.AffineTransform.y_offset', index=2,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4086,
  serialized_end=4163,
)

_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='epl.protobuf.v1.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_PARAMS_BUFFER, _PARAMS_GEODETICBUFFER, _PARAMS_CONVEX, _PARAMS_RELATE, _PARAMS_RANDOMPOINTS, _PARAMS_GENERALIZE, _PARAMS_GENERALIZEBYAREA, _PARAMS_INTERSECTION, _PARAMS_OFFSET, _PARAMS_CUT, _PARAMS_CLIP, _PARAMS_DENSIFY, _PARAMS_SIMPLIFY, _PARAMS_AFFINETRANSFORM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3184,
  serialized_end=4163,
)

_GEOMETRYDATA.fields_by_name['proj'].message_type = _PROJECTIONDATA
_GEOMETRYDATA.fields_by_name['envelope'].message_type = _ENVELOPEDATA
_GEOMETRYDATA.fields_by_name['simple'].enum_type = _SIMPLESTATE
_GEOMETRYDATA.oneofs_by_name['data'].fields.append(
  _GEOMETRYDATA.fields_by_name['wkt'])
_GEOMETRYDATA.fields_by_name['wkt'].containing_oneof = _GEOMETRYDATA.oneofs_by_name['data']
_GEOMETRYDATA.oneofs_by_name['data'].fields.append(
  _GEOMETRYDATA.fields_by_name['geojson'])
_GEOMETRYDATA.fields_by_name['geojson'].containing_oneof = _GEOMETRYDATA.oneofs_by_name['data']
_GEOMETRYDATA.oneofs_by_name['data'].fields.append(
  _GEOMETRYDATA.fields_by_name['wkb'])
_GEOMETRYDATA.fields_by_name['wkb'].containing_oneof = _GEOMETRYDATA.oneofs_by_name['data']
_GEOMETRYDATA.oneofs_by_name['data'].fields.append(
  _GEOMETRYDATA.fields_by_name['esri_shape'])
_GEOMETRYDATA.fields_by_name['esri_shape'].containing_oneof = _GEOMETRYDATA.oneofs_by_name['data']
_PROJECTIONDATA_CUSTOM.fields_by_name['cs_type'].enum_type = _PROJECTIONDATA_CSTYPE
_PROJECTIONDATA_CUSTOM.containing_type = _PROJECTIONDATA
_PROJECTIONDATA.fields_by_name['custom'].message_type = _PROJECTIONDATA_CUSTOM
_PROJECTIONDATA.fields_by_name['geometry'].message_type = _GEOMETRYDATA
_PROJECTIONDATA.fields_by_name['bbox'].message_type = _ENVELOPEDATA
_PROJECTIONDATA.fields_by_name['centroid'].message_type = _GEOMETRYDATA
_PROJECTIONDATA_CSTYPE.containing_type = _PROJECTIONDATA
_PROJECTIONDATA.oneofs_by_name['definition'].fields.append(
  _PROJECTIONDATA.fields_by_name['epsg'])
_PROJECTIONDATA.fields_by_name['epsg'].containing_oneof = _PROJECTIONDATA.oneofs_by_name['definition']
_PROJECTIONDATA.oneofs_by_name['definition'].fields.append(
  _PROJECTIONDATA.fields_by_name['proj4'])
_PROJECTIONDATA.fields_by_name['proj4'].containing_oneof = _PROJECTIONDATA.oneofs_by_name['definition']
_PROJECTIONDATA.oneofs_by_name['definition'].fields.append(
  _PROJECTIONDATA.fields_by_name['custom'])
_PROJECTIONDATA.fields_by_name['custom'].containing_oneof = _PROJECTIONDATA.oneofs_by_name['definition']
_PROJECTIONDATA.oneofs_by_name['definition'].fields.append(
  _PROJECTIONDATA.fields_by_name['wkt'])
_PROJECTIONDATA.fields_by_name['wkt'].containing_oneof = _PROJECTIONDATA.oneofs_by_name['definition']
_ENVELOPEDATA.fields_by_name['proj'].message_type = _PROJECTIONDATA
_GEOMETRYREQUEST.fields_by_name['geometry'].message_type = _GEOMETRYDATA
_GEOMETRYREQUEST.fields_by_name['left_geometry'].message_type = _GEOMETRYDATA
_GEOMETRYREQUEST.fields_by_name['geometry_request'].message_type = _GEOMETRYREQUEST
_GEOMETRYREQUEST.fields_by_name['left_geometry_request'].message_type = _GEOMETRYREQUEST
_GEOMETRYREQUEST.fields_by_name['right_geometry'].message_type = _GEOMETRYDATA
_GEOMETRYREQUEST.fields_by_name['right_geometry_request'].message_type = _GEOMETRYREQUEST
_GEOMETRYREQUEST.fields_by_name['operator'].enum_type = _OPERATORTYPE
_GEOMETRYREQUEST.fields_by_name['result_encoding'].enum_type = _ENCODING
_GEOMETRYREQUEST.fields_by_name['operation_proj'].message_type = _PROJECTIONDATA
_GEOMETRYREQUEST.fields_by_name['result_proj'].message_type = _PROJECTIONDATA
_GEOMETRYREQUEST.fields_by_name['buffer_params'].message_type = _PARAMS_BUFFER
_GEOMETRYREQUEST.fields_by_name['convex_params'].message_type = _PARAMS_CONVEX
_GEOMETRYREQUEST.fields_by_name['relate_params'].message_type = _PARAMS_RELATE
_GEOMETRYREQUEST.fields_by_name['random_points_params'].message_type = _PARAMS_RANDOMPOINTS
_GEOMETRYREQUEST.fields_by_name['generalize_params'].message_type = _PARAMS_GENERALIZE
_GEOMETRYREQUEST.fields_by_name['intersection_params'].message_type = _PARAMS_INTERSECTION
_GEOMETRYREQUEST.fields_by_name['offset_params'].message_type = _PARAMS_OFFSET
_GEOMETRYREQUEST.fields_by_name['cut_params'].message_type = _PARAMS_CUT
_GEOMETRYREQUEST.fields_by_name['clip_params'].message_type = _PARAMS_CLIP
_GEOMETRYREQUEST.fields_by_name['densify_params'].message_type = _PARAMS_DENSIFY
_GEOMETRYREQUEST.fields_by_name['simplify_params'].message_type = _PARAMS_SIMPLIFY
_GEOMETRYREQUEST.fields_by_name['generalize_by_area_params'].message_type = _PARAMS_GENERALIZEBYAREA
_GEOMETRYREQUEST.fields_by_name['affine_transform_params'].message_type = _PARAMS_AFFINETRANSFORM
_GEOMETRYREQUEST.fields_by_name['geodetic_buffer_params'].message_type = _PARAMS_GEODETICBUFFER
_GEOMETRYREQUEST.oneofs_by_name['left'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['geometry'])
_GEOMETRYREQUEST.fields_by_name['geometry'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['left']
_GEOMETRYREQUEST.oneofs_by_name['left'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['left_geometry'])
_GEOMETRYREQUEST.fields_by_name['left_geometry'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['left']
_GEOMETRYREQUEST.oneofs_by_name['left'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['geometry_request'])
_GEOMETRYREQUEST.fields_by_name['geometry_request'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['left']
_GEOMETRYREQUEST.oneofs_by_name['left'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['left_geometry_request'])
_GEOMETRYREQUEST.fields_by_name['left_geometry_request'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['left']
_GEOMETRYREQUEST.oneofs_by_name['right'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['right_geometry'])
_GEOMETRYREQUEST.fields_by_name['right_geometry'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['right']
_GEOMETRYREQUEST.oneofs_by_name['right'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['right_geometry_request'])
_GEOMETRYREQUEST.fields_by_name['right_geometry_request'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['right']
_GEOMETRYREQUEST.oneofs_by_name['params'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['buffer_params'])
_GEOMETRYREQUEST.fields_by_name['buffer_params'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['params']
_GEOMETRYREQUEST.oneofs_by_name['params'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['convex_params'])
_GEOMETRYREQUEST.fields_by_name['convex_params'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['params']
_GEOMETRYREQUEST.oneofs_by_name['params'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['relate_params'])
_GEOMETRYREQUEST.fields_by_name['relate_params'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['params']
_GEOMETRYREQUEST.oneofs_by_name['params'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['random_points_params'])
_GEOMETRYREQUEST.fields_by_name['random_points_params'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['params']
_GEOMETRYREQUEST.oneofs_by_name['params'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['generalize_params'])
_GEOMETRYREQUEST.fields_by_name['generalize_params'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['params']
_GEOMETRYREQUEST.oneofs_by_name['params'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['intersection_params'])
_GEOMETRYREQUEST.fields_by_name['intersection_params'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['params']
_GEOMETRYREQUEST.oneofs_by_name['params'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['offset_params'])
_GEOMETRYREQUEST.fields_by_name['offset_params'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['params']
_GEOMETRYREQUEST.oneofs_by_name['params'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['cut_params'])
_GEOMETRYREQUEST.fields_by_name['cut_params'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['params']
_GEOMETRYREQUEST.oneofs_by_name['params'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['clip_params'])
_GEOMETRYREQUEST.fields_by_name['clip_params'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['params']
_GEOMETRYREQUEST.oneofs_by_name['params'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['densify_params'])
_GEOMETRYREQUEST.fields_by_name['densify_params'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['params']
_GEOMETRYREQUEST.oneofs_by_name['params'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['simplify_params'])
_GEOMETRYREQUEST.fields_by_name['simplify_params'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['params']
_GEOMETRYREQUEST.oneofs_by_name['params'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['generalize_by_area_params'])
_GEOMETRYREQUEST.fields_by_name['generalize_by_area_params'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['params']
_GEOMETRYREQUEST.oneofs_by_name['params'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['affine_transform_params'])
_GEOMETRYREQUEST.fields_by_name['affine_transform_params'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['params']
_GEOMETRYREQUEST.oneofs_by_name['params'].fields.append(
  _GEOMETRYREQUEST.fields_by_name['geodetic_buffer_params'])
_GEOMETRYREQUEST.fields_by_name['geodetic_buffer_params'].containing_oneof = _GEOMETRYREQUEST.oneofs_by_name['params']
_GEOMETRYRESPONSE_RELATEMAPENTRY.containing_type = _GEOMETRYRESPONSE
_GEOMETRYRESPONSE.fields_by_name['geometry'].message_type = _GEOMETRYDATA
_GEOMETRYRESPONSE.fields_by_name['geodetic_inverse'].message_type = _GEODETICINVERSE
_GEOMETRYRESPONSE.fields_by_name['relate_map'].message_type = _GEOMETRYRESPONSE_RELATEMAPENTRY
_GEOMETRYRESPONSE.oneofs_by_name['result'].fields.append(
  _GEOMETRYRESPONSE.fields_by_name['geometry'])
_GEOMETRYRESPONSE.fields_by_name['geometry'].containing_oneof = _GEOMETRYRESPONSE.oneofs_by_name['result']
_GEOMETRYRESPONSE.oneofs_by_name['result'].fields.append(
  _GEOMETRYRESPONSE.fields_by_name['spatial_relationship'])
_GEOMETRYRESPONSE.fields_by_name['spatial_relationship'].containing_oneof = _GEOMETRYRESPONSE.oneofs_by_name['result']
_GEOMETRYRESPONSE.oneofs_by_name['result'].fields.append(
  _GEOMETRYRESPONSE.fields_by_name['measure'])
_GEOMETRYRESPONSE.fields_by_name['measure'].containing_oneof = _GEOMETRYRESPONSE.oneofs_by_name['result']
_GEOMETRYRESPONSE.oneofs_by_name['result'].fields.append(
  _GEOMETRYRESPONSE.fields_by_name['geodetic_inverse'])
_GEOMETRYRESPONSE.fields_by_name['geodetic_inverse'].containing_oneof = _GEOMETRYRESPONSE.oneofs_by_name['result']
_FILEREQUESTCHUNK.fields_by_name['nested_request'].message_type = _GEOMETRYREQUEST
_FILEREQUESTCHUNK.fields_by_name['result_encoding_type'].enum_type = _ENCODING
_FILEREQUESTCHUNK.fields_by_name['input_proj'].message_type = _PROJECTIONDATA
_FILEREQUESTCHUNK.fields_by_name['result_proj'].message_type = _PROJECTIONDATA
_FILEREQUESTCHUNK_FILETYPE.containing_type = _FILEREQUESTCHUNK
_PARAMS_BUFFER.containing_type = _PARAMS
_PARAMS_GEODETICBUFFER.containing_type = _PARAMS
_PARAMS_CONVEX.containing_type = _PARAMS
_PARAMS_RELATE.containing_type = _PARAMS
_PARAMS_RANDOMPOINTS.containing_type = _PARAMS
_PARAMS_GENERALIZE.containing_type = _PARAMS
_PARAMS_GENERALIZEBYAREA.containing_type = _PARAMS
_PARAMS_INTERSECTION.containing_type = _PARAMS
_PARAMS_OFFSET.fields_by_name['join_type'].enum_type = _PARAMS_OFFSET_OFFSETJOINTYPE
_PARAMS_OFFSET.containing_type = _PARAMS
_PARAMS_OFFSET_OFFSETJOINTYPE.containing_type = _PARAMS_OFFSET
_PARAMS_CUT.containing_type = _PARAMS
_PARAMS_CLIP.fields_by_name['envelope'].message_type = _ENVELOPEDATA
_PARAMS_CLIP.containing_type = _PARAMS
_PARAMS_DENSIFY.containing_type = _PARAMS
_PARAMS_SIMPLIFY.containing_type = _PARAMS
_PARAMS_AFFINETRANSFORM.containing_type = _PARAMS
DESCRIPTOR.message_types_by_name['GeometryData'] = _GEOMETRYDATA
DESCRIPTOR.message_types_by_name['ProjectionData'] = _PROJECTIONDATA
DESCRIPTOR.message_types_by_name['EnvelopeData'] = _ENVELOPEDATA
DESCRIPTOR.message_types_by_name['GeometryRequest'] = _GEOMETRYREQUEST
DESCRIPTOR.message_types_by_name['GeodeticInverse'] = _GEODETICINVERSE
DESCRIPTOR.message_types_by_name['GeometryResponse'] = _GEOMETRYRESPONSE
DESCRIPTOR.message_types_by_name['FileRequestChunk'] = _FILEREQUESTCHUNK
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.enum_types_by_name['SimpleState'] = _SIMPLESTATE
DESCRIPTOR.enum_types_by_name['Encoding'] = _ENCODING
DESCRIPTOR.enum_types_by_name['OperatorType'] = _OPERATORTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GeometryData = _reflection.GeneratedProtocolMessageType('GeometryData', (_message.Message,), {
  'DESCRIPTOR' : _GEOMETRYDATA,
  '__module__' : 'epl.protobuf.v1.geometry_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.GeometryData)
  })
_sym_db.RegisterMessage(GeometryData)

ProjectionData = _reflection.GeneratedProtocolMessageType('ProjectionData', (_message.Message,), {

  'Custom' : _reflection.GeneratedProtocolMessageType('Custom', (_message.Message,), {
    'DESCRIPTOR' : _PROJECTIONDATA_CUSTOM,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.ProjectionData.Custom)
    })
  ,
  'DESCRIPTOR' : _PROJECTIONDATA,
  '__module__' : 'epl.protobuf.v1.geometry_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.ProjectionData)
  })
_sym_db.RegisterMessage(ProjectionData)
_sym_db.RegisterMessage(ProjectionData.Custom)

EnvelopeData = _reflection.GeneratedProtocolMessageType('EnvelopeData', (_message.Message,), {
  'DESCRIPTOR' : _ENVELOPEDATA,
  '__module__' : 'epl.protobuf.v1.geometry_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.EnvelopeData)
  })
_sym_db.RegisterMessage(EnvelopeData)

GeometryRequest = _reflection.GeneratedProtocolMessageType('GeometryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GEOMETRYREQUEST,
  '__module__' : 'epl.protobuf.v1.geometry_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.GeometryRequest)
  })
_sym_db.RegisterMessage(GeometryRequest)

GeodeticInverse = _reflection.GeneratedProtocolMessageType('GeodeticInverse', (_message.Message,), {
  'DESCRIPTOR' : _GEODETICINVERSE,
  '__module__' : 'epl.protobuf.v1.geometry_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.GeodeticInverse)
  })
_sym_db.RegisterMessage(GeodeticInverse)

GeometryResponse = _reflection.GeneratedProtocolMessageType('GeometryResponse', (_message.Message,), {

  'RelateMapEntry' : _reflection.GeneratedProtocolMessageType('RelateMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _GEOMETRYRESPONSE_RELATEMAPENTRY,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.GeometryResponse.RelateMapEntry)
    })
  ,
  'DESCRIPTOR' : _GEOMETRYRESPONSE,
  '__module__' : 'epl.protobuf.v1.geometry_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.GeometryResponse)
  })
_sym_db.RegisterMessage(GeometryResponse)
_sym_db.RegisterMessage(GeometryResponse.RelateMapEntry)

FileRequestChunk = _reflection.GeneratedProtocolMessageType('FileRequestChunk', (_message.Message,), {
  'DESCRIPTOR' : _FILEREQUESTCHUNK,
  '__module__' : 'epl.protobuf.v1.geometry_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.FileRequestChunk)
  })
_sym_db.RegisterMessage(FileRequestChunk)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {

  'Buffer' : _reflection.GeneratedProtocolMessageType('Buffer', (_message.Message,), {
    'DESCRIPTOR' : _PARAMS_BUFFER,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Params.Buffer)
    })
  ,

  'GeodeticBuffer' : _reflection.GeneratedProtocolMessageType('GeodeticBuffer', (_message.Message,), {
    'DESCRIPTOR' : _PARAMS_GEODETICBUFFER,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Params.GeodeticBuffer)
    })
  ,

  'Convex' : _reflection.GeneratedProtocolMessageType('Convex', (_message.Message,), {
    'DESCRIPTOR' : _PARAMS_CONVEX,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Params.Convex)
    })
  ,

  'Relate' : _reflection.GeneratedProtocolMessageType('Relate', (_message.Message,), {
    'DESCRIPTOR' : _PARAMS_RELATE,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Params.Relate)
    })
  ,

  'RandomPoints' : _reflection.GeneratedProtocolMessageType('RandomPoints', (_message.Message,), {
    'DESCRIPTOR' : _PARAMS_RANDOMPOINTS,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Params.RandomPoints)
    })
  ,

  'Generalize' : _reflection.GeneratedProtocolMessageType('Generalize', (_message.Message,), {
    'DESCRIPTOR' : _PARAMS_GENERALIZE,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Params.Generalize)
    })
  ,

  'GeneralizeByArea' : _reflection.GeneratedProtocolMessageType('GeneralizeByArea', (_message.Message,), {
    'DESCRIPTOR' : _PARAMS_GENERALIZEBYAREA,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Params.GeneralizeByArea)
    })
  ,

  'Intersection' : _reflection.GeneratedProtocolMessageType('Intersection', (_message.Message,), {
    'DESCRIPTOR' : _PARAMS_INTERSECTION,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Params.Intersection)
    })
  ,

  'Offset' : _reflection.GeneratedProtocolMessageType('Offset', (_message.Message,), {
    'DESCRIPTOR' : _PARAMS_OFFSET,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Params.Offset)
    })
  ,

  'Cut' : _reflection.GeneratedProtocolMessageType('Cut', (_message.Message,), {
    'DESCRIPTOR' : _PARAMS_CUT,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Params.Cut)
    })
  ,

  'Clip' : _reflection.GeneratedProtocolMessageType('Clip', (_message.Message,), {
    'DESCRIPTOR' : _PARAMS_CLIP,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Params.Clip)
    })
  ,

  'Densify' : _reflection.GeneratedProtocolMessageType('Densify', (_message.Message,), {
    'DESCRIPTOR' : _PARAMS_DENSIFY,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Params.Densify)
    })
  ,

  'Simplify' : _reflection.GeneratedProtocolMessageType('Simplify', (_message.Message,), {
    'DESCRIPTOR' : _PARAMS_SIMPLIFY,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Params.Simplify)
    })
  ,

  'AffineTransform' : _reflection.GeneratedProtocolMessageType('AffineTransform', (_message.Message,), {
    'DESCRIPTOR' : _PARAMS_AFFINETRANSFORM,
    '__module__' : 'epl.protobuf.v1.geometry_pb2'
    # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Params.AffineTransform)
    })
  ,
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'epl.protobuf.v1.geometry_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.Params)
  })
_sym_db.RegisterMessage(Params)
_sym_db.RegisterMessage(Params.Buffer)
_sym_db.RegisterMessage(Params.GeodeticBuffer)
_sym_db.RegisterMessage(Params.Convex)
_sym_db.RegisterMessage(Params.Relate)
_sym_db.RegisterMessage(Params.RandomPoints)
_sym_db.RegisterMessage(Params.Generalize)
_sym_db.RegisterMessage(Params.GeneralizeByArea)
_sym_db.RegisterMessage(Params.Intersection)
_sym_db.RegisterMessage(Params.Offset)
_sym_db.RegisterMessage(Params.Cut)
_sym_db.RegisterMessage(Params.Clip)
_sym_db.RegisterMessage(Params.Densify)
_sym_db.RegisterMessage(Params.Simplify)
_sym_db.RegisterMessage(Params.AffineTransform)


DESCRIPTOR._options = None
_GEOMETRYRESPONSE_RELATEMAPENTRY._options = None
# @@protoc_insertion_point(module_scope)
